import pymel.core as pm
from alShaders import *

class AEcryptomatteTemplate(alShadersTemplate):
	controls = {}
	params = {}
	def setup(self):
		self.params.clear()
		self.params["sidecarManifests"] = Param("sidecarManifests", "Sidecar Manifests", "Sets whether Cryptomatte should write the manifest to a sidecar .json file instead of the EXR header.", "bool", presets=None)
		self.params["cryptomatteDepth"] = Param("cryptomatteDepth", "Cryptomatte Depth", "Set the cryptomatte depth (number of cryptomatte AOVs)", "int", presets=None)
		self.params["stripObjNamespaces"] = Param("stripObjNamespaces", "Strip Object Namespaces", "Strip namespaces from object names", "bool", presets=None)
		self.params["stripMatNamespaces"] = Param("stripMatNamespaces", "Strip Material Namespaces", "Strip namespaces from material names", "bool", presets=None)
		self.params["aovCryptoAsset"] = Param("aovCryptoAsset", "Asset AOV name", "", "rgb", presets=None)
		self.params["aovCryptoObject"] = Param("aovCryptoObject", "Object AOV name", "", "rgb", presets=None)
		self.params["aovCryptoMaterial"] = Param("aovCryptoMaterial", "Material AOV name", "", "rgb", presets=None)
		self.params["userCryptoAov0"] = Param("userCryptoAov0", "AOV name", "AOV name for user Cryptomatte 0", "string", presets=None)
		self.params["userCryptoSrc0"] = Param("userCryptoSrc0", "Source User Data", "Source user data name for user Cryptomatte 0", "string", presets=None)
		self.params["userCryptoAov1"] = Param("userCryptoAov1", "AOV name", "AOV name for user Cryptomatte 1", "string", presets=None)
		self.params["userCryptoSrc1"] = Param("userCryptoSrc1", "Source User Data", "Source user data name for user Cryptomatte 1", "string", presets=None)
		self.params["userCryptoAov2"] = Param("userCryptoAov2", "AOV name", "AOV name for user Cryptomatte 2", "string", presets=None)
		self.params["userCryptoSrc2"] = Param("userCryptoSrc2", "Source User Data", "Source user data name for user Cryptomatte 2", "string", presets=None)
		self.params["userCryptoAov3"] = Param("userCryptoAov3", "AOV name", "AOV name for user Cryptomatte 3", "string", presets=None)
		self.params["userCryptoSrc3"] = Param("userCryptoSrc3", "Source User Data", "Source user data name for user Cryptomatte 3", "string", presets=None)

		self.beginScrollLayout()

		self.beginLayout("Cryptomatte Globals", collapse=False)
		self.addControl("sidecarManifests", label="Sidecar Manifests", annotation="Sets whether Cryptomatte should write the manifest to a sidecar .json file instead of the EXR header.")
		self.addControl("cryptomatteDepth", label="Cryptomatte Depth", annotation="Set the cryptomatte depth (number of cryptomatte AOVs)")
		self.addControl("stripObjNamespaces", label="Strip Object Namespaces", annotation="Strip namespaces from object names")
		self.addControl("stripMatNamespaces", label="Strip Material Namespaces", annotation="Strip namespaces from material names")
		self.endLayout() # END Cryptomatte Globals
		self.beginLayout("Standard Cryptomatte AOVs", collapse=False)
		self.addControl("aovCryptoAsset", label="Asset AOV name", annotation="")
		self.addControl("aovCryptoObject", label="Object AOV name", annotation="")
		self.addControl("aovCryptoMaterial", label="Material AOV name", annotation="")
		self.endLayout() # END Standard Cryptomatte AOVs
		self.beginLayout("User Defined Cryptomattes", collapse=True)
		self.beginLayout("User Cryptomatte 0", collapse=False)
		self.addControl("userCryptoAov0", label="AOV name", annotation="AOV name for user Cryptomatte 0")
		self.addControl("userCryptoSrc0", label="Source User Data", annotation="Source user data name for user Cryptomatte 0")
		self.endLayout() # END User Cryptomatte 0
		self.beginLayout("User Cryptomatte 1", collapse=False)
		self.addControl("userCryptoAov1", label="AOV name", annotation="AOV name for user Cryptomatte 1")
		self.addControl("userCryptoSrc1", label="Source User Data", annotation="Source user data name for user Cryptomatte 1")
		self.endLayout() # END User Cryptomatte 1
		self.beginLayout("User Cryptomatte 2", collapse=False)
		self.addControl("userCryptoAov2", label="AOV name", annotation="AOV name for user Cryptomatte 2")
		self.addControl("userCryptoSrc2", label="Source User Data", annotation="Source user data name for user Cryptomatte 2")
		self.endLayout() # END User Cryptomatte 2
		self.beginLayout("User Cryptomatte 3", collapse=False)
		self.addControl("userCryptoAov3", label="AOV name", annotation="AOV name for user Cryptomatte 3")
		self.addControl("userCryptoSrc3", label="Source User Data", annotation="Source user data name for user Cryptomatte 3")
		self.endLayout() # END User Cryptomatte 3
		self.endLayout() # END User Defined Cryptomattes

		pm.mel.AEdependNodeTemplate(self.nodeName)
		self.addExtraControls()

		self.endScrollLayout()
